==> kubernetes-model-storageclass-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/storage/VolumeAttachmentListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VolumeAttachmentListFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent<A>{
  public VolumeAttachmentListFluentImpl() {
  }
  public VolumeAttachmentListFluentImpl(io.fabric8.kubernetes.api.model.storage.VolumeAttachmentList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private java.lang.String apiVersion;
  private java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> items =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ListMeta metadata;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public A addToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(java.util.Collection<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(java.util.Collection<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> getItems() {
    return build(items);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> buildItems() {
    return build(items);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildItem(java.lang.Integer index) {
    return this.items.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildFirstItem() {
    return this.items.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>(); for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item :items){ this.addToItems(item);}} return (A) this;
  }
  public java.lang.Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> addNewItem() {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> setNewItemLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editItem(java.lang.Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(java.lang.String _continue,java.lang.Long remainingItemCount,java.lang.String resourceVersion,java.lang.String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VolumeAttachmentListFluentImpl that = (VolumeAttachmentListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public class ItemsNestedImpl<N> extends io.fabric8.kubernetes.api.model.storage.VolumeAttachmentFluentImpl<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<N>> implements io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ItemsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(this);
    }
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) VolumeAttachmentListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-storageclass-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/storage/VolumeAttachmentListFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class VolumeAttachmentListFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent<A>{
  public VolumeAttachmentListFluentImpl() {
  }
  public VolumeAttachmentListFluentImpl(io.fabric8.kubernetes.api.model.storage.VolumeAttachmentList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> items =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ListMeta metadata;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public A addToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(java.util.Collection<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    if (this.items == null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>();}
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(java.util.Collection<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items) {io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> getItems() {
    return build(items);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> buildItems() {
    return build(items);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildItem(java.lang.Integer index) {
    return this.items.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildFirstItem() {
    return this.items.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachment buildMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(java.util.List<io.fabric8.kubernetes.api.model.storage.VolumeAttachment> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new java.util.ArrayList<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder>(); for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.kubernetes.api.model.storage.VolumeAttachment... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (io.fabric8.kubernetes.api.model.storage.VolumeAttachment item :items){ this.addToItems(item);}} return (A) this;
  }
  public java.lang.Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> addNewItem() {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> setNewItemLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
    return new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluentImpl.ItemsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editItem(java.lang.Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<A> editMatchingItem(java.util.function.Predicate<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(java.lang.String _continue,java.lang.Long remainingItemCount,java.lang.String resourceVersion,java.lang.String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VolumeAttachmentListFluentImpl that = (VolumeAttachmentListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public class ItemsNestedImpl<N> extends io.fabric8.kubernetes.api.model.storage.VolumeAttachmentFluentImpl<io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<N>> implements io.fabric8.kubernetes.api.model.storage.VolumeAttachmentListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ItemsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.storage.VolumeAttachment item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder(this);
    }
    io.fabric8.kubernetes.api.model.storage.VolumeAttachmentBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) VolumeAttachmentListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
